@@ -1,20 +1,8 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
-   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "stepgraphicsitem.h"
@@ -58,7 +46,7 @@ StepGraphicsItem::StepGraphicsItem(StepCore::Item* item, WorldModel* worldModel,
     , _isMouseOverItem(false)
     , _isSelected(false)
     , _isMoving(false)
-    , _onHoverHandler(0)
+    , _onHoverHandler(nullptr)
     , _onHoverHandlerTimer(false)
 {
     // XXX: use persistent indexes here and in propertiesbrowser
@@ -73,7 +61,11 @@ double StepGraphicsItem::currentViewScale() const
 
 QColor StepGraphicsItem::highlightColor(const QColor& color)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    float h, s, v, a;
+#else
     qreal h, s, v, a;
+#endif
     QColor hsv = color.toHsv();
     hsv.getHsvF(&h, &s, &v, &a);
 
@@ -154,7 +146,7 @@ void StepGraphicsItem::drawCircularArrow(QPainter* painter, double angle, double
 void StepGraphicsItem::mouseSetPos(const QPointF& pos, const QPointF&, MovingState)
 {
     const StepCore::MetaProperty* property = _item->metaObject()->property(QStringLiteral("position"));
-    if(property != NULL) {
+    if(property != nullptr) {
         _worldModel->simulationPause();
         _worldModel->setProperty(_item, property,
                                 QVariant::fromValue( pointToVector(pos) ));
